==> chewing-editor_0.0.1.orig.tar.gz: chewing-editor-0.0.1/ts/chewing-editor_en_US.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US">
<context>
    <name>ChewingEditor</name>
    <message>
        <location filename="../src/ui/ChewingEditor.ui" line="20"/>
        <source>Chewing user phrase editor</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ChewingEditor.ui" line="40"/>
        <source>Filter</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ChewingEditor.ui" line="57"/>
        <source>File</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ChewingEditor.ui" line="64"/>
        <source>Edit</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ChewingEditor.ui" line="72"/>
        <source>Help</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ChewingEditor.ui" line="83"/>
        <source>Import</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ChewingEditor.ui" line="88"/>
        <source>Export</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ChewingEditor.ui" line="93"/>
        <source>Add phrase</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ChewingEditor.ui" line="98"/>
        <source>Remove phrase</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ChewingEditor.ui" line="103"/>
        <source>Refresh</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ChewingEditor.ui" line="108"/>
        <source>About Chewing editor</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ChewingEditor.ui" line="113"/>
        <source>About Qt</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Notification</name>
    <message>
        <location filename="../src/view/Notification.cpp" line="39"/>
        <source>%1 %2 %3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/view/Notification.cpp" line="44"/>
        <source>Import %1 failed.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/view/Notification.cpp" line="57"/>
        <source>%1 %2</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/view/Notification.cpp" line="40"/>
        <source>Import %1 successful.</source>
        <translation></translation>
    </message>
    <message numerus="yes">
        <location filename="../src/view/Notification.cpp" line="41"/>
        <source>%n phrase(s) are imported.</source>
        <translation>
            <numerusform>%n phrase is imported.</numerusform>
            <numerusform>%n phrases are imported.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/view/Notification.cpp" line="42"/>
        <source>Total %n user phrase(s).</source>
        <translation>
            <numerusform>Total %n user phrase.</numerusform>
            <numerusform>Total %n user phrases.</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../src/view/Notification.cpp" line="58"/>
        <source>Export %1 successful.</source>
        <translation></translation>
    </message>
    <message numerus="yes">
        <location filename="../src/view/Notification.cpp" line="59"/>
        <source>%n phrase(s) are exported.</source>
        <translation>
            <numerusform>%n phrase is exported.</numerusform>
            <numerusform>%n phrases are exported.</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../src/view/Notification.cpp" line="61"/>
        <source>Export %1 failed.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/view/Notification.cpp" line="69"/>
        <source>Add new phrase %1 successful.</source>
        <translation></translation>
    </message>
    <message numerus="yes">
        <location filename="../src/view/Notification.cpp" line="77"/>
        <source>Remove %n phrase(s) successful.</source>
        <translation>
            <numerusform>Remove %n phrase successful.</numerusform>
            <numerusform>Remove %n phrases successful.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/view/Notification.cpp" line="84"/>
        <source>Refresh completed. Total %n user phrase(s).</source>
        <translation>
            <numerusform>Refresh completed. Total %n user phrase.</numerusform>
            <numerusform>Refresh completed. Total %n user phrases.</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>UserphraseDialog</name>
    <message>
        <location filename="../src/ui/UserphraseDialog.ui" line="20"/>
        <source>Add new user phrase</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/UserphraseDialog.ui" line="38"/>
        <source>phrase</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/UserphraseDialog.ui" line="48"/>
        <source>bopomofo</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>UserphraseViewMenu</name>
    <message>
        <location filename="../src/ui/UserphraseViewMenu.ui" line="7"/>
        <source>Add</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/UserphraseViewMenu.ui" line="12"/>
        <source>Modify</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/UserphraseViewMenu.ui" line="17"/>
        <source>Remove</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../src/main.cpp" line="88"/>
        <source>%1
</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="101"/>
        <source>chewing-editor is a cross platform chewing user phrase editor written in Qt5. It provides a user friendly GUI to manage user phrase. With it, user can customize user phrase to enhance chewing input performance.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="109"/>
        <source>-d, --debug</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="110"/>
        <source>Enable debug message.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="113"/>
        <source>-v, --version</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="114"/>
        <source>Print program version.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="117"/>
        <source>-h, --help</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="118"/>
        <source>Print help message.</source>
        <translation></translation>
    </message>
</context>
</TS>

==> chewing-editor_0.0.4.orig.tar.gz: chewing-editor-0.0.4/ts/chewing-editor_en_US.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="en_US">
<context>
    <name>ChewingEditor</name>
    <message>
        <location filename="../src/ui/ChewingEditor.ui" line="20"/>
        <source>Chewing user phrase editor</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ChewingEditor.ui" line="75"/>
        <source>File</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ChewingEditor.ui" line="27"/>
        <source>Add</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ChewingEditor.ui" line="34"/>
        <source>Remove</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ChewingEditor.ui" line="48"/>
        <source>Search</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ChewingEditor.ui" line="84"/>
        <source>Help</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ChewingEditor.ui" line="94"/>
        <source>&amp;Import</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ChewingEditor.ui" line="99"/>
        <source>&amp;Export</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ChewingEditor.ui" line="114"/>
        <source>E&amp;xit</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ChewingEditor.ui" line="41"/>
        <source>Refresh</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ChewingEditor.ui" line="104"/>
        <source>About Chewing editor</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/ChewingEditor.ui" line="109"/>
        <source>About Qt</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/view/ChewingEditor.cpp" line="69"/>
        <source>Import</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/view/ChewingEditor.cpp" line="77"/>
        <source>Export</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>Notification</name>
    <message>
        <location filename="../src/view/Notification.cpp" line="39"/>
        <source>%1 %2 %3</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/view/Notification.cpp" line="57"/>
        <source>%1 %2</source>
        <translation></translation>
    </message>
    <message numerus="yes">
        <location filename="../src/view/Notification.cpp" line="41"/>
        <source>%n phrase(s) are imported.</source>
        <translation>
            <numerusform>%n phrase is imported.</numerusform>
            <numerusform>%n phrases are imported.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/view/Notification.cpp" line="42"/>
        <source>Total %n user phrase(s).</source>
        <translation>
            <numerusform>Total %n user phrase.</numerusform>
            <numerusform>Total %n user phrases.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/view/Notification.cpp" line="59"/>
        <source>%n phrase(s) are exported.</source>
        <translation>
            <numerusform>%n phrase is exported.</numerusform>
            <numerusform>%n phrases are exported.</numerusform>
        </translation>
    </message>
    <message>
        <location filename="../src/view/Notification.cpp" line="40"/>
        <source>Import &quot;%1&quot; successful.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/view/Notification.cpp" line="44"/>
        <source>Import &quot;%1&quot; failed.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/view/Notification.cpp" line="58"/>
        <source>Export &quot;%1&quot; successful.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/view/Notification.cpp" line="61"/>
        <source>Export &quot;%1&quot; failed.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/view/Notification.cpp" line="69"/>
        <source>Add new phrase %1 successful.</source>
        <translation></translation>
    </message>
    <message numerus="yes">
        <location filename="../src/view/Notification.cpp" line="77"/>
        <source>Remove %n phrase(s) successful.</source>
        <translation>
            <numerusform>Remove %n phrase successful.</numerusform>
            <numerusform>Remove %n phrases successful.</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <location filename="../src/view/Notification.cpp" line="84"/>
        <source>Refresh completed. Total %n user phrase(s).</source>
        <translation>
            <numerusform>Refresh completed. Total %n user phrase.</numerusform>
            <numerusform>Refresh completed. Total %n user phrases.</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>UserphraseDialog</name>
    <message>
        <location filename="../src/ui/UserphraseDialog.ui" line="14"/>
        <source>Add new phrase</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/UserphraseDialog.ui" line="25"/>
        <source>Phrase:</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/UserphraseDialog.ui" line="35"/>
        <source>Bopomofo:</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>UserphraseView</name>
    <message>
        <location filename="../src/view/UserphraseView.cpp" line="43"/>
        <source>Add new phrase</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/view/UserphraseView.cpp" line="58"/>
        <source>Modify phrase</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>UserphraseViewMenu</name>
    <message>
        <location filename="../src/ui/UserphraseViewMenu.ui" line="7"/>
        <source>Add</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/UserphraseViewMenu.ui" line="12"/>
        <source>Modify</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/UserphraseViewMenu.ui" line="17"/>
        <source>Remove</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../src/main.cpp" line="92"/>
        <source>%1
</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="105"/>
        <source>chewing-editor is a cross platform chewing user phrase editor written in Qt5. It provides a user friendly GUI to manage user phrase. With it, user can customize user phrase to enhance chewing input performance.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="113"/>
        <source>-d, --debug</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="114"/>
        <source>Enable debug message.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="117"/>
        <source>-v, --version</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="118"/>
        <source>Print program version.</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="121"/>
        <source>-h, --help</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/main.cpp" line="122"/>
        <source>Print help message.</source>
        <translation></translation>
    </message>
</context>
</TS>
